@@ -1,6 +1,6 @@
 package Module::Path;
 # ABSTRACT: get the full path to a locally installed module
-$Module::Path::VERSION = '0.11_02';
+$Module::Path::VERSION = '0.11_03';
 use 5.006;
 use strict;
 use warnings;
@@ -35,9 +35,11 @@ sub module_path
 
     DIRECTORY:
     foreach my $dir (@INC) {
+        next DIRECTORY if not defined($dir);
+
         # see 'perldoc -f require' on why you might find
         # a reference in @INC
-        next if ref($dir);
+        next DIRECTORY if ref($dir);
 
         # The directory path might have a symlink somewhere in it,
         # so we get an absolute path (ie resolve any symlinks).
